==> webkit_1.4.3.orig.tar.gz: webkit-1.4.3/Source/WebCore/storage/SQLResultSet.h <==
/*
 * Copyright (C) 2007 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 * 3.  Neither the name of Apple Computer, Inc. ("Apple") nor the names of
 *     its contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE AND ITS CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE OR ITS CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef SQLResultSet_h
#define SQLResultSet_h

#if ENABLE(DATABASE)

#include "ExceptionCode.h"
#include "SQLResultSetRowList.h"
#include <wtf/ThreadSafeShared.h>

namespace WebCore {

class SQLResultSet : public ThreadSafeShared<SQLResultSet> {
public:
    static PassRefPtr<SQLResultSet> create() { return adoptRef(new SQLResultSet); }

    SQLResultSetRowList* rows() const;

    int64_t insertId(ExceptionCode&) const;
    int rowsAffected() const;

// For internal (non-JS) use
    void setInsertId(int64_t);
    void setRowsAffected(int);

private:
    SQLResultSet();

    RefPtr<SQLResultSetRowList> m_rows;
    int64_t m_insertId;
    bool m_insertIdSet;
    int m_rowsAffected;
};

} // namespace WebCore

#endif

#endif // SQLResultSet_h

==> webkit-1.6.1.tar.gz: webkit-1.6.1/Source/WebCore/storage/SQLResultSet.h <==
/*
 * Copyright (C) 2007 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 * 3.  Neither the name of Apple Computer, Inc. ("Apple") nor the names of
 *     its contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE AND ITS CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE OR ITS CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef SQLResultSet_h
#define SQLResultSet_h

#if ENABLE(SQL_DATABASE)

#include "ExceptionCode.h"
#include "SQLResultSetRowList.h"
#include <wtf/ThreadSafeRefCounted.h>

namespace WebCore {

class SQLResultSet : public ThreadSafeRefCounted<SQLResultSet> {
public:
    static PassRefPtr<SQLResultSet> create() { return adoptRef(new SQLResultSet); }

    SQLResultSetRowList* rows() const;

    int64_t insertId(ExceptionCode&) const;
    int rowsAffected() const;

// For internal (non-JS) use
    void setInsertId(int64_t);
    void setRowsAffected(int);

private:
    SQLResultSet();

    RefPtr<SQLResultSetRowList> m_rows;
    int64_t m_insertId;
    bool m_insertIdSet;
    int m_rowsAffected;
};

} // namespace WebCore

#endif

#endif // SQLResultSet_h
